# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetConnectionResult',
    'AwaitableGetConnectionResult',
    'get_connection',
    'get_connection_output',
]

@pulumi.output_type
class GetConnectionResult:
    """
    A collection of values returned by getConnection.
    """
    def __init__(__self__, auth_scheme=None, base_url=None, id=None, profile=None, status=None):
        if auth_scheme and not isinstance(auth_scheme, str):
            raise TypeError("Expected argument 'auth_scheme' to be a str")
        pulumi.set(__self__, "auth_scheme", auth_scheme)
        if base_url and not isinstance(base_url, str):
            raise TypeError("Expected argument 'base_url' to be a str")
        pulumi.set(__self__, "base_url", base_url)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if profile and not isinstance(profile, dict):
            raise TypeError("Expected argument 'profile' to be a dict")
        pulumi.set(__self__, "profile", profile)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="authScheme")
    def auth_scheme(self) -> _builtins.str:
        """
        A token is used to authenticate with the app. This property is only returned for the TOKEN authentication scheme.
        """
        return pulumi.get(self, "auth_scheme")

    @_builtins.property
    @pulumi.getter(name="baseUrl")
    def base_url(self) -> _builtins.str:
        """
        The base URL for the provisioning connection.
        """
        return pulumi.get(self, "base_url")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The application ID for which to retrieve the provisioning connection information.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def profile(self) -> Optional['outputs.GetConnectionProfileResult']:
        """
        Profile information for the app connection.
        """
        return pulumi.get(self, "profile")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        Provisioning connection status.
        """
        return pulumi.get(self, "status")


class AwaitableGetConnectionResult(GetConnectionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetConnectionResult(
            auth_scheme=self.auth_scheme,
            base_url=self.base_url,
            id=self.id,
            profile=self.profile,
            status=self.status)


def get_connection(auth_scheme: Optional[_builtins.str] = None,
                   base_url: Optional[_builtins.str] = None,
                   id: Optional[_builtins.str] = None,
                   profile: Optional[Union['GetConnectionProfileArgs', 'GetConnectionProfileArgsDict']] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetConnectionResult:
    """
    Retrieves the default provisioning connection for an app.

    ## Example Usage

    ### Basic Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.app.get_connection(id="0oa1234567890abcdef")
    pulumi.export("connectionStatus", example.status)
    ```


    :param _builtins.str auth_scheme: A token is used to authenticate with the app. This property is only returned for the TOKEN authentication scheme.
    :param _builtins.str base_url: The base URL for the provisioning connection.
    :param _builtins.str id: The application ID for which to retrieve the provisioning connection information.
    :param Union['GetConnectionProfileArgs', 'GetConnectionProfileArgsDict'] profile: Profile information for the app connection.
    """
    __args__ = dict()
    __args__['authScheme'] = auth_scheme
    __args__['baseUrl'] = base_url
    __args__['id'] = id
    __args__['profile'] = profile
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:app/getConnection:getConnection', __args__, opts=opts, typ=GetConnectionResult).value

    return AwaitableGetConnectionResult(
        auth_scheme=pulumi.get(__ret__, 'auth_scheme'),
        base_url=pulumi.get(__ret__, 'base_url'),
        id=pulumi.get(__ret__, 'id'),
        profile=pulumi.get(__ret__, 'profile'),
        status=pulumi.get(__ret__, 'status'))
def get_connection_output(auth_scheme: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          base_url: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          id: Optional[pulumi.Input[_builtins.str]] = None,
                          profile: Optional[pulumi.Input[Optional[Union['GetConnectionProfileArgs', 'GetConnectionProfileArgsDict']]]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetConnectionResult]:
    """
    Retrieves the default provisioning connection for an app.

    ## Example Usage

    ### Basic Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.app.get_connection(id="0oa1234567890abcdef")
    pulumi.export("connectionStatus", example.status)
    ```


    :param _builtins.str auth_scheme: A token is used to authenticate with the app. This property is only returned for the TOKEN authentication scheme.
    :param _builtins.str base_url: The base URL for the provisioning connection.
    :param _builtins.str id: The application ID for which to retrieve the provisioning connection information.
    :param Union['GetConnectionProfileArgs', 'GetConnectionProfileArgsDict'] profile: Profile information for the app connection.
    """
    __args__ = dict()
    __args__['authScheme'] = auth_scheme
    __args__['baseUrl'] = base_url
    __args__['id'] = id
    __args__['profile'] = profile
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:app/getConnection:getConnection', __args__, opts=opts, typ=GetConnectionResult)
    return __ret__.apply(lambda __response__: GetConnectionResult(
        auth_scheme=pulumi.get(__response__, 'auth_scheme'),
        base_url=pulumi.get(__response__, 'base_url'),
        id=pulumi.get(__response__, 'id'),
        profile=pulumi.get(__response__, 'profile'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['SecurityNotificationEmailsArgs', 'SecurityNotificationEmails']

@pulumi.input_type
class SecurityNotificationEmailsArgs:
    def __init__(__self__, *,
                 report_suspicious_activity_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 send_email_for_factor_enrollment_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 send_email_for_factor_reset_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 send_email_for_new_device_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 send_email_for_password_changed_enabled: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a SecurityNotificationEmails resource.
        :param pulumi.Input[_builtins.bool] report_suspicious_activity_enabled: Notifies end users about suspicious or unrecognized activity from their account. Default is `true`.
        :param pulumi.Input[_builtins.bool] send_email_for_factor_enrollment_enabled: Notifies end users of any activity on their account related to MFA factor enrollment. Default is `true`.
        :param pulumi.Input[_builtins.bool] send_email_for_factor_reset_enabled: Notifies end users that one or more factors have been reset for their account. Default is `true`.
        :param pulumi.Input[_builtins.bool] send_email_for_new_device_enabled: Notifies end users about new sign-on activity. Default is `true`.
        :param pulumi.Input[_builtins.bool] send_email_for_password_changed_enabled: Notifies end users that the password for their account has changed. Default is `true`.
        """
        if report_suspicious_activity_enabled is not None:
            pulumi.set(__self__, "report_suspicious_activity_enabled", report_suspicious_activity_enabled)
        if send_email_for_factor_enrollment_enabled is not None:
            pulumi.set(__self__, "send_email_for_factor_enrollment_enabled", send_email_for_factor_enrollment_enabled)
        if send_email_for_factor_reset_enabled is not None:
            pulumi.set(__self__, "send_email_for_factor_reset_enabled", send_email_for_factor_reset_enabled)
        if send_email_for_new_device_enabled is not None:
            pulumi.set(__self__, "send_email_for_new_device_enabled", send_email_for_new_device_enabled)
        if send_email_for_password_changed_enabled is not None:
            pulumi.set(__self__, "send_email_for_password_changed_enabled", send_email_for_password_changed_enabled)

    @_builtins.property
    @pulumi.getter(name="reportSuspiciousActivityEnabled")
    def report_suspicious_activity_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Notifies end users about suspicious or unrecognized activity from their account. Default is `true`.
        """
        return pulumi.get(self, "report_suspicious_activity_enabled")

    @report_suspicious_activity_enabled.setter
    def report_suspicious_activity_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "report_suspicious_activity_enabled", value)

    @_builtins.property
    @pulumi.getter(name="sendEmailForFactorEnrollmentEnabled")
    def send_email_for_factor_enrollment_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Notifies end users of any activity on their account related to MFA factor enrollment. Default is `true`.
        """
        return pulumi.get(self, "send_email_for_factor_enrollment_enabled")

    @send_email_for_factor_enrollment_enabled.setter
    def send_email_for_factor_enrollment_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "send_email_for_factor_enrollment_enabled", value)

    @_builtins.property
    @pulumi.getter(name="sendEmailForFactorResetEnabled")
    def send_email_for_factor_reset_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Notifies end users that one or more factors have been reset for their account. Default is `true`.
        """
        return pulumi.get(self, "send_email_for_factor_reset_enabled")

    @send_email_for_factor_reset_enabled.setter
    def send_email_for_factor_reset_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "send_email_for_factor_reset_enabled", value)

    @_builtins.property
    @pulumi.getter(name="sendEmailForNewDeviceEnabled")
    def send_email_for_new_device_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Notifies end users about new sign-on activity. Default is `true`.
        """
        return pulumi.get(self, "send_email_for_new_device_enabled")

    @send_email_for_new_device_enabled.setter
    def send_email_for_new_device_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "send_email_for_new_device_enabled", value)

    @_builtins.property
    @pulumi.getter(name="sendEmailForPasswordChangedEnabled")
    def send_email_for_password_changed_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Notifies end users that the password for their account has changed. Default is `true`.
        """
        return pulumi.get(self, "send_email_for_password_changed_enabled")

    @send_email_for_password_changed_enabled.setter
    def send_email_for_password_changed_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "send_email_for_password_changed_enabled", value)


@pulumi.input_type
class _SecurityNotificationEmailsState:
    def __init__(__self__, *,
                 report_suspicious_activity_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 send_email_for_factor_enrollment_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 send_email_for_factor_reset_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 send_email_for_new_device_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 send_email_for_password_changed_enabled: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering SecurityNotificationEmails resources.
        :param pulumi.Input[_builtins.bool] report_suspicious_activity_enabled: Notifies end users about suspicious or unrecognized activity from their account. Default is `true`.
        :param pulumi.Input[_builtins.bool] send_email_for_factor_enrollment_enabled: Notifies end users of any activity on their account related to MFA factor enrollment. Default is `true`.
        :param pulumi.Input[_builtins.bool] send_email_for_factor_reset_enabled: Notifies end users that one or more factors have been reset for their account. Default is `true`.
        :param pulumi.Input[_builtins.bool] send_email_for_new_device_enabled: Notifies end users about new sign-on activity. Default is `true`.
        :param pulumi.Input[_builtins.bool] send_email_for_password_changed_enabled: Notifies end users that the password for their account has changed. Default is `true`.
        """
        if report_suspicious_activity_enabled is not None:
            pulumi.set(__self__, "report_suspicious_activity_enabled", report_suspicious_activity_enabled)
        if send_email_for_factor_enrollment_enabled is not None:
            pulumi.set(__self__, "send_email_for_factor_enrollment_enabled", send_email_for_factor_enrollment_enabled)
        if send_email_for_factor_reset_enabled is not None:
            pulumi.set(__self__, "send_email_for_factor_reset_enabled", send_email_for_factor_reset_enabled)
        if send_email_for_new_device_enabled is not None:
            pulumi.set(__self__, "send_email_for_new_device_enabled", send_email_for_new_device_enabled)
        if send_email_for_password_changed_enabled is not None:
            pulumi.set(__self__, "send_email_for_password_changed_enabled", send_email_for_password_changed_enabled)

    @_builtins.property
    @pulumi.getter(name="reportSuspiciousActivityEnabled")
    def report_suspicious_activity_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Notifies end users about suspicious or unrecognized activity from their account. Default is `true`.
        """
        return pulumi.get(self, "report_suspicious_activity_enabled")

    @report_suspicious_activity_enabled.setter
    def report_suspicious_activity_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "report_suspicious_activity_enabled", value)

    @_builtins.property
    @pulumi.getter(name="sendEmailForFactorEnrollmentEnabled")
    def send_email_for_factor_enrollment_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Notifies end users of any activity on their account related to MFA factor enrollment. Default is `true`.
        """
        return pulumi.get(self, "send_email_for_factor_enrollment_enabled")

    @send_email_for_factor_enrollment_enabled.setter
    def send_email_for_factor_enrollment_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "send_email_for_factor_enrollment_enabled", value)

    @_builtins.property
    @pulumi.getter(name="sendEmailForFactorResetEnabled")
    def send_email_for_factor_reset_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Notifies end users that one or more factors have been reset for their account. Default is `true`.
        """
        return pulumi.get(self, "send_email_for_factor_reset_enabled")

    @send_email_for_factor_reset_enabled.setter
    def send_email_for_factor_reset_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "send_email_for_factor_reset_enabled", value)

    @_builtins.property
    @pulumi.getter(name="sendEmailForNewDeviceEnabled")
    def send_email_for_new_device_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Notifies end users about new sign-on activity. Default is `true`.
        """
        return pulumi.get(self, "send_email_for_new_device_enabled")

    @send_email_for_new_device_enabled.setter
    def send_email_for_new_device_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "send_email_for_new_device_enabled", value)

    @_builtins.property
    @pulumi.getter(name="sendEmailForPasswordChangedEnabled")
    def send_email_for_password_changed_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Notifies end users that the password for their account has changed. Default is `true`.
        """
        return pulumi.get(self, "send_email_for_password_changed_enabled")

    @send_email_for_password_changed_enabled.setter
    def send_email_for_password_changed_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "send_email_for_password_changed_enabled", value)


@pulumi.type_token("okta:index/securityNotificationEmails:SecurityNotificationEmails")
class SecurityNotificationEmails(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 report_suspicious_activity_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 send_email_for_factor_enrollment_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 send_email_for_factor_reset_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 send_email_for_new_device_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 send_email_for_password_changed_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Manages Security Notification Emails
        		This resource allows you to configure Security Notification Emails.
        		> **WARNING:** This resource is available only when using a SSWS API token in the provider config, it is incompatible with OAuth 2.0 authentication.
        		> **WARNING:** This resource makes use of an internal/private Okta API endpoint that could change without notice rendering this resource inoperable.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.SecurityNotificationEmails("example",
            report_suspicious_activity_enabled=True,
            send_email_for_factor_enrollment_enabled=True,
            send_email_for_factor_reset_enabled=True,
            send_email_for_new_device_enabled=True,
            send_email_for_password_changed_enabled=True)
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/securityNotificationEmails:SecurityNotificationEmails example _
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] report_suspicious_activity_enabled: Notifies end users about suspicious or unrecognized activity from their account. Default is `true`.
        :param pulumi.Input[_builtins.bool] send_email_for_factor_enrollment_enabled: Notifies end users of any activity on their account related to MFA factor enrollment. Default is `true`.
        :param pulumi.Input[_builtins.bool] send_email_for_factor_reset_enabled: Notifies end users that one or more factors have been reset for their account. Default is `true`.
        :param pulumi.Input[_builtins.bool] send_email_for_new_device_enabled: Notifies end users about new sign-on activity. Default is `true`.
        :param pulumi.Input[_builtins.bool] send_email_for_password_changed_enabled: Notifies end users that the password for their account has changed. Default is `true`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[SecurityNotificationEmailsArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Security Notification Emails
        		This resource allows you to configure Security Notification Emails.
        		> **WARNING:** This resource is available only when using a SSWS API token in the provider config, it is incompatible with OAuth 2.0 authentication.
        		> **WARNING:** This resource makes use of an internal/private Okta API endpoint that could change without notice rendering this resource inoperable.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.SecurityNotificationEmails("example",
            report_suspicious_activity_enabled=True,
            send_email_for_factor_enrollment_enabled=True,
            send_email_for_factor_reset_enabled=True,
            send_email_for_new_device_enabled=True,
            send_email_for_password_changed_enabled=True)
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/securityNotificationEmails:SecurityNotificationEmails example _
        ```

        :param str resource_name: The name of the resource.
        :param SecurityNotificationEmailsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecurityNotificationEmailsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 report_suspicious_activity_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 send_email_for_factor_enrollment_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 send_email_for_factor_reset_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 send_email_for_new_device_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 send_email_for_password_changed_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecurityNotificationEmailsArgs.__new__(SecurityNotificationEmailsArgs)

            __props__.__dict__["report_suspicious_activity_enabled"] = report_suspicious_activity_enabled
            __props__.__dict__["send_email_for_factor_enrollment_enabled"] = send_email_for_factor_enrollment_enabled
            __props__.__dict__["send_email_for_factor_reset_enabled"] = send_email_for_factor_reset_enabled
            __props__.__dict__["send_email_for_new_device_enabled"] = send_email_for_new_device_enabled
            __props__.__dict__["send_email_for_password_changed_enabled"] = send_email_for_password_changed_enabled
        super(SecurityNotificationEmails, __self__).__init__(
            'okta:index/securityNotificationEmails:SecurityNotificationEmails',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            report_suspicious_activity_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            send_email_for_factor_enrollment_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            send_email_for_factor_reset_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            send_email_for_new_device_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            send_email_for_password_changed_enabled: Optional[pulumi.Input[_builtins.bool]] = None) -> 'SecurityNotificationEmails':
        """
        Get an existing SecurityNotificationEmails resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] report_suspicious_activity_enabled: Notifies end users about suspicious or unrecognized activity from their account. Default is `true`.
        :param pulumi.Input[_builtins.bool] send_email_for_factor_enrollment_enabled: Notifies end users of any activity on their account related to MFA factor enrollment. Default is `true`.
        :param pulumi.Input[_builtins.bool] send_email_for_factor_reset_enabled: Notifies end users that one or more factors have been reset for their account. Default is `true`.
        :param pulumi.Input[_builtins.bool] send_email_for_new_device_enabled: Notifies end users about new sign-on activity. Default is `true`.
        :param pulumi.Input[_builtins.bool] send_email_for_password_changed_enabled: Notifies end users that the password for their account has changed. Default is `true`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecurityNotificationEmailsState.__new__(_SecurityNotificationEmailsState)

        __props__.__dict__["report_suspicious_activity_enabled"] = report_suspicious_activity_enabled
        __props__.__dict__["send_email_for_factor_enrollment_enabled"] = send_email_for_factor_enrollment_enabled
        __props__.__dict__["send_email_for_factor_reset_enabled"] = send_email_for_factor_reset_enabled
        __props__.__dict__["send_email_for_new_device_enabled"] = send_email_for_new_device_enabled
        __props__.__dict__["send_email_for_password_changed_enabled"] = send_email_for_password_changed_enabled
        return SecurityNotificationEmails(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="reportSuspiciousActivityEnabled")
    def report_suspicious_activity_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Notifies end users about suspicious or unrecognized activity from their account. Default is `true`.
        """
        return pulumi.get(self, "report_suspicious_activity_enabled")

    @_builtins.property
    @pulumi.getter(name="sendEmailForFactorEnrollmentEnabled")
    def send_email_for_factor_enrollment_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Notifies end users of any activity on their account related to MFA factor enrollment. Default is `true`.
        """
        return pulumi.get(self, "send_email_for_factor_enrollment_enabled")

    @_builtins.property
    @pulumi.getter(name="sendEmailForFactorResetEnabled")
    def send_email_for_factor_reset_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Notifies end users that one or more factors have been reset for their account. Default is `true`.
        """
        return pulumi.get(self, "send_email_for_factor_reset_enabled")

    @_builtins.property
    @pulumi.getter(name="sendEmailForNewDeviceEnabled")
    def send_email_for_new_device_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Notifies end users about new sign-on activity. Default is `true`.
        """
        return pulumi.get(self, "send_email_for_new_device_enabled")

    @_builtins.property
    @pulumi.getter(name="sendEmailForPasswordChangedEnabled")
    def send_email_for_password_changed_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Notifies end users that the password for their account has changed. Default is `true`.
        """
        return pulumi.get(self, "send_email_for_password_changed_enabled")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetRuleResult',
    'AwaitableGetRuleResult',
    'get_rule',
    'get_rule_output',
]

@pulumi.output_type
class GetRuleResult:
    """
    A collection of values returned by getRule.
    """
    def __init__(__self__, expression_type=None, expression_value=None, group_assignments=None, id=None, name=None, status=None, users_excludeds=None):
        if expression_type and not isinstance(expression_type, str):
            raise TypeError("Expected argument 'expression_type' to be a str")
        pulumi.set(__self__, "expression_type", expression_type)
        if expression_value and not isinstance(expression_value, str):
            raise TypeError("Expected argument 'expression_value' to be a str")
        pulumi.set(__self__, "expression_value", expression_value)
        if group_assignments and not isinstance(group_assignments, list):
            raise TypeError("Expected argument 'group_assignments' to be a list")
        pulumi.set(__self__, "group_assignments", group_assignments)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if users_excludeds and not isinstance(users_excludeds, list):
            raise TypeError("Expected argument 'users_excludeds' to be a list")
        pulumi.set(__self__, "users_excludeds", users_excludeds)

    @_builtins.property
    @pulumi.getter(name="expressionType")
    def expression_type(self) -> _builtins.str:
        """
        The expression type to use to invoke the rule.
        """
        return pulumi.get(self, "expression_type")

    @_builtins.property
    @pulumi.getter(name="expressionValue")
    def expression_value(self) -> _builtins.str:
        """
        The expression value.
        """
        return pulumi.get(self, "expression_value")

    @_builtins.property
    @pulumi.getter(name="groupAssignments")
    def group_assignments(self) -> Sequence[_builtins.str]:
        """
        The list of group ids to assign the users to.
        """
        return pulumi.get(self, "group_assignments")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        The ID of the Group Rule.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        The name of the Group Rule.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[_builtins.str]:
        """
        Default to `ACTIVE`
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="usersExcludeds")
    def users_excludeds(self) -> Sequence[_builtins.str]:
        """
        The list of user IDs that would be excluded when rules are processed.
        """
        return pulumi.get(self, "users_excludeds")


class AwaitableGetRuleResult(GetRuleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRuleResult(
            expression_type=self.expression_type,
            expression_value=self.expression_value,
            group_assignments=self.group_assignments,
            id=self.id,
            name=self.name,
            status=self.status,
            users_excludeds=self.users_excludeds)


def get_rule(id: Optional[_builtins.str] = None,
             name: Optional[_builtins.str] = None,
             status: Optional[_builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRuleResult:
    """
    Get a group rule from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.group.get_rule(id=example["id"])
    ```


    :param _builtins.str id: The ID of the Group Rule.
    :param _builtins.str name: The name of the Group Rule.
    :param _builtins.str status: Default to `ACTIVE`
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:group/getRule:getRule', __args__, opts=opts, typ=GetRuleResult).value

    return AwaitableGetRuleResult(
        expression_type=pulumi.get(__ret__, 'expression_type'),
        expression_value=pulumi.get(__ret__, 'expression_value'),
        group_assignments=pulumi.get(__ret__, 'group_assignments'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        status=pulumi.get(__ret__, 'status'),
        users_excludeds=pulumi.get(__ret__, 'users_excludeds'))
def get_rule_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    status: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRuleResult]:
    """
    Get a group rule from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.group.get_rule(id=example["id"])
    ```


    :param _builtins.str id: The ID of the Group Rule.
    :param _builtins.str name: The name of the Group Rule.
    :param _builtins.str status: Default to `ACTIVE`
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['status'] = status
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:group/getRule:getRule', __args__, opts=opts, typ=GetRuleResult)
    return __ret__.apply(lambda __response__: GetRuleResult(
        expression_type=pulumi.get(__response__, 'expression_type'),
        expression_value=pulumi.get(__response__, 'expression_value'),
        group_assignments=pulumi.get(__response__, 'group_assignments'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        status=pulumi.get(__response__, 'status'),
        users_excludeds=pulumi.get(__response__, 'users_excludeds')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ApiTokenArgs', 'ApiToken']

@pulumi.input_type
class ApiTokenArgs:
    def __init__(__self__, *,
                 id_property: pulumi.Input[_builtins.str],
                 client_name: Optional[pulumi.Input[_builtins.str]] = None,
                 created: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network: Optional[pulumi.Input['ApiTokenNetworkArgs']] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ApiToken resource.
        :param pulumi.Input[_builtins.str] id_property: The ID of the API token.
        :param pulumi.Input[_builtins.str] client_name: The name of the API token client.
        :param pulumi.Input[_builtins.str] created: The date and time the API token was created.
        :param pulumi.Input[_builtins.str] name: The name of the API token.
        :param pulumi.Input['ApiTokenNetworkArgs'] network: The Network Condition of the API Token.
        :param pulumi.Input[_builtins.str] user_id: The userId of the user who created the API Token.
        """
        pulumi.set(__self__, "id_property", id_property)
        if client_name is not None:
            pulumi.set(__self__, "client_name", client_name)
        if created is not None:
            pulumi.set(__self__, "created", created)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network is not None:
            pulumi.set(__self__, "network", network)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the API token.
        """
        return pulumi.get(self, "id_property")

    @id_property.setter
    def id_property(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "id_property", value)

    @_builtins.property
    @pulumi.getter(name="clientName")
    def client_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the API token client.
        """
        return pulumi.get(self, "client_name")

    @client_name.setter
    def client_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "client_name", value)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time the API token was created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the API token.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def network(self) -> Optional[pulumi.Input['ApiTokenNetworkArgs']]:
        """
        The Network Condition of the API Token.
        """
        return pulumi.get(self, "network")

    @network.setter
    def network(self, value: Optional[pulumi.Input['ApiTokenNetworkArgs']]):
        pulumi.set(self, "network", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The userId of the user who created the API Token.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.input_type
class _ApiTokenState:
    def __init__(__self__, *,
                 client_name: Optional[pulumi.Input[_builtins.str]] = None,
                 created: Optional[pulumi.Input[_builtins.str]] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network: Optional[pulumi.Input['ApiTokenNetworkArgs']] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ApiToken resources.
        :param pulumi.Input[_builtins.str] client_name: The name of the API token client.
        :param pulumi.Input[_builtins.str] created: The date and time the API token was created.
        :param pulumi.Input[_builtins.str] id_property: The ID of the API token.
        :param pulumi.Input[_builtins.str] name: The name of the API token.
        :param pulumi.Input['ApiTokenNetworkArgs'] network: The Network Condition of the API Token.
        :param pulumi.Input[_builtins.str] user_id: The userId of the user who created the API Token.
        """
        if client_name is not None:
            pulumi.set(__self__, "client_name", client_name)
        if created is not None:
            pulumi.set(__self__, "created", created)
        if id_property is not None:
            pulumi.set(__self__, "id_property", id_property)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network is not None:
            pulumi.set(__self__, "network", network)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="clientName")
    def client_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the API token client.
        """
        return pulumi.get(self, "client_name")

    @client_name.setter
    def client_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "client_name", value)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time the API token was created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created", value)

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the API token.
        """
        return pulumi.get(self, "id_property")

    @id_property.setter
    def id_property(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id_property", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the API token.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def network(self) -> Optional[pulumi.Input['ApiTokenNetworkArgs']]:
        """
        The Network Condition of the API Token.
        """
        return pulumi.get(self, "network")

    @network.setter
    def network(self, value: Optional[pulumi.Input['ApiTokenNetworkArgs']]):
        pulumi.set(self, "network", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The userId of the user who created the API Token.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.type_token("okta:index/apiToken:ApiToken")
class ApiToken(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_name: Optional[pulumi.Input[_builtins.str]] = None,
                 created: Optional[pulumi.Input[_builtins.str]] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network: Optional[pulumi.Input[Union['ApiTokenNetworkArgs', 'ApiTokenNetworkArgsDict']]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.ApiToken("example",
            id_property="00T1fxzubpqiepH11d38",
            name="token-api-token-test",
            user_id="00unkw1sfbTw08c0g1d7",
            network={
                "connection": "ZONE",
                "excludes": ["nzonkw1sfwwi79Hat2d7"],
            },
            client_name="Okta API")
        ```

        ## Nested Schema for network

        ### Optional:
        - `connection` (String) The connection type of the Network Condition.

        ### Blocks:
        - `exclude` (List of String) List of excluded network zones.
        - `include` (List of String) List of included network zones.

        ### Import
        API tokens can be imported using their ID:

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] client_name: The name of the API token client.
        :param pulumi.Input[_builtins.str] created: The date and time the API token was created.
        :param pulumi.Input[_builtins.str] id_property: The ID of the API token.
        :param pulumi.Input[_builtins.str] name: The name of the API token.
        :param pulumi.Input[Union['ApiTokenNetworkArgs', 'ApiTokenNetworkArgsDict']] network: The Network Condition of the API Token.
        :param pulumi.Input[_builtins.str] user_id: The userId of the user who created the API Token.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApiTokenArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.ApiToken("example",
            id_property="00T1fxzubpqiepH11d38",
            name="token-api-token-test",
            user_id="00unkw1sfbTw08c0g1d7",
            network={
                "connection": "ZONE",
                "excludes": ["nzonkw1sfwwi79Hat2d7"],
            },
            client_name="Okta API")
        ```

        ## Nested Schema for network

        ### Optional:
        - `connection` (String) The connection type of the Network Condition.

        ### Blocks:
        - `exclude` (List of String) List of excluded network zones.
        - `include` (List of String) List of included network zones.

        ### Import
        API tokens can be imported using their ID:

        :param str resource_name: The name of the resource.
        :param ApiTokenArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApiTokenArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_name: Optional[pulumi.Input[_builtins.str]] = None,
                 created: Optional[pulumi.Input[_builtins.str]] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network: Optional[pulumi.Input[Union['ApiTokenNetworkArgs', 'ApiTokenNetworkArgsDict']]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApiTokenArgs.__new__(ApiTokenArgs)

            __props__.__dict__["client_name"] = client_name
            __props__.__dict__["created"] = created
            if id_property is None and not opts.urn:
                raise TypeError("Missing required property 'id_property'")
            __props__.__dict__["id_property"] = id_property
            __props__.__dict__["name"] = name
            __props__.__dict__["network"] = network
            __props__.__dict__["user_id"] = user_id
        super(ApiToken, __self__).__init__(
            'okta:index/apiToken:ApiToken',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            client_name: Optional[pulumi.Input[_builtins.str]] = None,
            created: Optional[pulumi.Input[_builtins.str]] = None,
            id_property: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            network: Optional[pulumi.Input[Union['ApiTokenNetworkArgs', 'ApiTokenNetworkArgsDict']]] = None,
            user_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'ApiToken':
        """
        Get an existing ApiToken resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] client_name: The name of the API token client.
        :param pulumi.Input[_builtins.str] created: The date and time the API token was created.
        :param pulumi.Input[_builtins.str] id_property: The ID of the API token.
        :param pulumi.Input[_builtins.str] name: The name of the API token.
        :param pulumi.Input[Union['ApiTokenNetworkArgs', 'ApiTokenNetworkArgsDict']] network: The Network Condition of the API Token.
        :param pulumi.Input[_builtins.str] user_id: The userId of the user who created the API Token.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApiTokenState.__new__(_ApiTokenState)

        __props__.__dict__["client_name"] = client_name
        __props__.__dict__["created"] = created
        __props__.__dict__["id_property"] = id_property
        __props__.__dict__["name"] = name
        __props__.__dict__["network"] = network
        __props__.__dict__["user_id"] = user_id
        return ApiToken(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="clientName")
    def client_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the API token client.
        """
        return pulumi.get(self, "client_name")

    @_builtins.property
    @pulumi.getter
    def created(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time the API token was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the API token.
        """
        return pulumi.get(self, "id_property")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the API token.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def network(self) -> pulumi.Output[Optional['outputs.ApiTokenNetwork']]:
        """
        The Network Condition of the API Token.
        """
        return pulumi.get(self, "network")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[_builtins.str]:
        """
        The userId of the user who created the API Token.
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetBehaviourResult',
    'AwaitableGetBehaviourResult',
    'get_behaviour',
    'get_behaviour_output',
]

@pulumi.output_type
class GetBehaviourResult:
    """
    A collection of values returned by getBehaviour.
    """
    def __init__(__self__, id=None, name=None, settings=None, status=None, type=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if settings and not isinstance(settings, dict):
            raise TypeError("Expected argument 'settings' to be a dict")
        pulumi.set(__self__, "settings", settings)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        Behavior ID.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Behavior name.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def settings(self) -> Mapping[str, _builtins.str]:
        """
        Map of behavior settings.
        """
        return pulumi.get(self, "settings")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        Behavior status.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Behavior type.
        """
        return pulumi.get(self, "type")


class AwaitableGetBehaviourResult(GetBehaviourResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBehaviourResult(
            id=self.id,
            name=self.name,
            settings=self.settings,
            status=self.status,
            type=self.type)


def get_behaviour(id: Optional[_builtins.str] = None,
                  name: Optional[_builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBehaviourResult:
    """
    Get a behavior by name or ID.

    ## Example Usage


    :param _builtins.str id: Behavior ID.
    :param _builtins.str name: Behavior name.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getBehaviour:getBehaviour', __args__, opts=opts, typ=GetBehaviourResult).value

    return AwaitableGetBehaviourResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        settings=pulumi.get(__ret__, 'settings'),
        status=pulumi.get(__ret__, 'status'),
        type=pulumi.get(__ret__, 'type'))
def get_behaviour_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBehaviourResult]:
    """
    Get a behavior by name or ID.

    ## Example Usage


    :param _builtins.str id: Behavior ID.
    :param _builtins.str name: Behavior name.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getBehaviour:getBehaviour', __args__, opts=opts, typ=GetBehaviourResult)
    return __ret__.apply(lambda __response__: GetBehaviourResult(
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        settings=pulumi.get(__response__, 'settings'),
        status=pulumi.get(__response__, 'status'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetRealmAssignmentResult',
    'AwaitableGetRealmAssignmentResult',
    'get_realm_assignment',
    'get_realm_assignment_output',
]

@pulumi.output_type
class GetRealmAssignmentResult:
    """
    A collection of values returned by getRealmAssignment.
    """
    def __init__(__self__, condition_expression=None, id=None, is_default=None, name=None, priority=None, profile_source_id=None, realm_id=None, status=None):
        if condition_expression and not isinstance(condition_expression, str):
            raise TypeError("Expected argument 'condition_expression' to be a str")
        pulumi.set(__self__, "condition_expression", condition_expression)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_default and not isinstance(is_default, bool):
            raise TypeError("Expected argument 'is_default' to be a bool")
        pulumi.set(__self__, "is_default", is_default)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if priority and not isinstance(priority, int):
            raise TypeError("Expected argument 'priority' to be a int")
        pulumi.set(__self__, "priority", priority)
        if profile_source_id and not isinstance(profile_source_id, str):
            raise TypeError("Expected argument 'profile_source_id' to be a str")
        pulumi.set(__self__, "profile_source_id", profile_source_id)
        if realm_id and not isinstance(realm_id, str):
            raise TypeError("Expected argument 'realm_id' to be a str")
        pulumi.set(__self__, "realm_id", realm_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="conditionExpression")
    def condition_expression(self) -> _builtins.str:
        """
        Condition expression for the Realm Assignment in Okta Expression Language. Example: `user.profile.role =="Manager"` or `user.profile.state.contains("example")`.
        """
        return pulumi.get(self, "condition_expression")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Realm Assignment ID.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> _builtins.bool:
        """
        Indicates whether the realm assignment is the default.
        """
        return pulumi.get(self, "is_default")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        The name of the Okta Realm Assignment.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def priority(self) -> _builtins.int:
        """
        The Priority of the Realm Assignment. The lower the number, the higher the priority.
        """
        return pulumi.get(self, "priority")

    @_builtins.property
    @pulumi.getter(name="profileSourceId")
    def profile_source_id(self) -> _builtins.str:
        """
        The ID of the Profile Source.
        """
        return pulumi.get(self, "profile_source_id")

    @_builtins.property
    @pulumi.getter(name="realmId")
    def realm_id(self) -> _builtins.str:
        """
        The ID of the Realm asscociated with the Realm Assignment.
        """
        return pulumi.get(self, "realm_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        Defines whether the Realm Assignment is active or not. Valid values: `ACTIVE` and `INACTIVE`.
        """
        return pulumi.get(self, "status")


class AwaitableGetRealmAssignmentResult(GetRealmAssignmentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRealmAssignmentResult(
            condition_expression=self.condition_expression,
            id=self.id,
            is_default=self.is_default,
            name=self.name,
            priority=self.priority,
            profile_source_id=self.profile_source_id,
            realm_id=self.realm_id,
            status=self.status)


def get_realm_assignment(name: Optional[_builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRealmAssignmentResult:
    """
    Get a realm assignment from Okta.

    ## Example Usage


    :param _builtins.str name: The name of the Okta Realm Assignment.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getRealmAssignment:getRealmAssignment', __args__, opts=opts, typ=GetRealmAssignmentResult).value

    return AwaitableGetRealmAssignmentResult(
        condition_expression=pulumi.get(__ret__, 'condition_expression'),
        id=pulumi.get(__ret__, 'id'),
        is_default=pulumi.get(__ret__, 'is_default'),
        name=pulumi.get(__ret__, 'name'),
        priority=pulumi.get(__ret__, 'priority'),
        profile_source_id=pulumi.get(__ret__, 'profile_source_id'),
        realm_id=pulumi.get(__ret__, 'realm_id'),
        status=pulumi.get(__ret__, 'status'))
def get_realm_assignment_output(name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRealmAssignmentResult]:
    """
    Get a realm assignment from Okta.

    ## Example Usage


    :param _builtins.str name: The name of the Okta Realm Assignment.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getRealmAssignment:getRealmAssignment', __args__, opts=opts, typ=GetRealmAssignmentResult)
    return __ret__.apply(lambda __response__: GetRealmAssignmentResult(
        condition_expression=pulumi.get(__response__, 'condition_expression'),
        id=pulumi.get(__response__, 'id'),
        is_default=pulumi.get(__response__, 'is_default'),
        name=pulumi.get(__response__, 'name'),
        priority=pulumi.get(__response__, 'priority'),
        profile_source_id=pulumi.get(__response__, 'profile_source_id'),
        realm_id=pulumi.get(__response__, 'realm_id'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EntitlementArgs', 'Entitlement']

@pulumi.input_type
class EntitlementArgs:
    def __init__(__self__, *,
                 data_type: pulumi.Input[_builtins.str],
                 external_value: pulumi.Input[_builtins.str],
                 multi_value: pulumi.Input[_builtins.bool],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input['EntitlementParentArgs']] = None,
                 parent_resource_orn: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 values: Optional[pulumi.Input[Sequence[pulumi.Input['EntitlementValueArgs']]]] = None):
        """
        The set of arguments for constructing a Entitlement resource.
        :param pulumi.Input[_builtins.str] data_type: The data type of the entitlement property. If the entitlement property is multivalued, the data type is replaced with an array. Enum: "array", "string".
        :param pulumi.Input[_builtins.str] external_value: The value of an entitlement property.
        :param pulumi.Input[_builtins.bool] multi_value: The property that determines if the entitlement property can hold multiple values.
        :param pulumi.Input[_builtins.str] description: The description of an entitlement property.
        :param pulumi.Input[_builtins.str] name: The display name for an entitlement property.
        :param pulumi.Input['EntitlementParentArgs'] parent: Representation of a resource
        :param pulumi.Input[_builtins.str] parent_resource_orn: The Okta app instance, in ORN format.
        :param pulumi.Input[_builtins.str] value: The value of the entitlement property.
        """
        pulumi.set(__self__, "data_type", data_type)
        pulumi.set(__self__, "external_value", external_value)
        pulumi.set(__self__, "multi_value", multi_value)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parent is not None:
            pulumi.set(__self__, "parent", parent)
        if parent_resource_orn is not None:
            pulumi.set(__self__, "parent_resource_orn", parent_resource_orn)
        if value is not None:
            pulumi.set(__self__, "value", value)
        if values is not None:
            pulumi.set(__self__, "values", values)

    @_builtins.property
    @pulumi.getter(name="dataType")
    def data_type(self) -> pulumi.Input[_builtins.str]:
        """
        The data type of the entitlement property. If the entitlement property is multivalued, the data type is replaced with an array. Enum: "array", "string".
        """
        return pulumi.get(self, "data_type")

    @data_type.setter
    def data_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "data_type", value)

    @_builtins.property
    @pulumi.getter(name="externalValue")
    def external_value(self) -> pulumi.Input[_builtins.str]:
        """
        The value of an entitlement property.
        """
        return pulumi.get(self, "external_value")

    @external_value.setter
    def external_value(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "external_value", value)

    @_builtins.property
    @pulumi.getter(name="multiValue")
    def multi_value(self) -> pulumi.Input[_builtins.bool]:
        """
        The property that determines if the entitlement property can hold multiple values.
        """
        return pulumi.get(self, "multi_value")

    @multi_value.setter
    def multi_value(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "multi_value", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of an entitlement property.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The display name for an entitlement property.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def parent(self) -> Optional[pulumi.Input['EntitlementParentArgs']]:
        """
        Representation of a resource
        """
        return pulumi.get(self, "parent")

    @parent.setter
    def parent(self, value: Optional[pulumi.Input['EntitlementParentArgs']]):
        pulumi.set(self, "parent", value)

    @_builtins.property
    @pulumi.getter(name="parentResourceOrn")
    def parent_resource_orn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Okta app instance, in ORN format.
        """
        return pulumi.get(self, "parent_resource_orn")

    @parent_resource_orn.setter
    def parent_resource_orn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent_resource_orn", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The value of the entitlement property.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter
    def values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EntitlementValueArgs']]]]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EntitlementValueArgs']]]]):
        pulumi.set(self, "values", value)


@pulumi.input_type
class _EntitlementState:
    def __init__(__self__, *,
                 data_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 external_value: Optional[pulumi.Input[_builtins.str]] = None,
                 multi_value: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input['EntitlementParentArgs']] = None,
                 parent_resource_orn: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 values: Optional[pulumi.Input[Sequence[pulumi.Input['EntitlementValueArgs']]]] = None):
        """
        Input properties used for looking up and filtering Entitlement resources.
        :param pulumi.Input[_builtins.str] data_type: The data type of the entitlement property. If the entitlement property is multivalued, the data type is replaced with an array. Enum: "array", "string".
        :param pulumi.Input[_builtins.str] description: The description of an entitlement property.
        :param pulumi.Input[_builtins.str] external_value: The value of an entitlement property.
        :param pulumi.Input[_builtins.bool] multi_value: The property that determines if the entitlement property can hold multiple values.
        :param pulumi.Input[_builtins.str] name: The display name for an entitlement property.
        :param pulumi.Input['EntitlementParentArgs'] parent: Representation of a resource
        :param pulumi.Input[_builtins.str] parent_resource_orn: The Okta app instance, in ORN format.
        :param pulumi.Input[_builtins.str] value: The value of the entitlement property.
        """
        if data_type is not None:
            pulumi.set(__self__, "data_type", data_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if external_value is not None:
            pulumi.set(__self__, "external_value", external_value)
        if multi_value is not None:
            pulumi.set(__self__, "multi_value", multi_value)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parent is not None:
            pulumi.set(__self__, "parent", parent)
        if parent_resource_orn is not None:
            pulumi.set(__self__, "parent_resource_orn", parent_resource_orn)
        if value is not None:
            pulumi.set(__self__, "value", value)
        if values is not None:
            pulumi.set(__self__, "values", values)

    @_builtins.property
    @pulumi.getter(name="dataType")
    def data_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The data type of the entitlement property. If the entitlement property is multivalued, the data type is replaced with an array. Enum: "array", "string".
        """
        return pulumi.get(self, "data_type")

    @data_type.setter
    def data_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "data_type", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of an entitlement property.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="externalValue")
    def external_value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The value of an entitlement property.
        """
        return pulumi.get(self, "external_value")

    @external_value.setter
    def external_value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_value", value)

    @_builtins.property
    @pulumi.getter(name="multiValue")
    def multi_value(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        The property that determines if the entitlement property can hold multiple values.
        """
        return pulumi.get(self, "multi_value")

    @multi_value.setter
    def multi_value(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "multi_value", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The display name for an entitlement property.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def parent(self) -> Optional[pulumi.Input['EntitlementParentArgs']]:
        """
        Representation of a resource
        """
        return pulumi.get(self, "parent")

    @parent.setter
    def parent(self, value: Optional[pulumi.Input['EntitlementParentArgs']]):
        pulumi.set(self, "parent", value)

    @_builtins.property
    @pulumi.getter(name="parentResourceOrn")
    def parent_resource_orn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Okta app instance, in ORN format.
        """
        return pulumi.get(self, "parent_resource_orn")

    @parent_resource_orn.setter
    def parent_resource_orn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent_resource_orn", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The value of the entitlement property.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter
    def values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EntitlementValueArgs']]]]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EntitlementValueArgs']]]]):
        pulumi.set(self, "values", value)


@pulumi.type_token("okta:index/entitlement:Entitlement")
class Entitlement(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 external_value: Optional[pulumi.Input[_builtins.str]] = None,
                 multi_value: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[Union['EntitlementParentArgs', 'EntitlementParentArgsDict']]] = None,
                 parent_resource_orn: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EntitlementValueArgs', 'EntitlementValueArgsDict']]]]] = None,
                 __props__=None):
        """
        Manages Entitlement. This resource allows you to create and configure an Okta [Entitlement](https://developer.okta.com/docs/api/iga/openapi/governance.api/tag/Entitlements/).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.Entitlement("example", name="example")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/entitlement:Entitlement example <entitlement_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] data_type: The data type of the entitlement property. If the entitlement property is multivalued, the data type is replaced with an array. Enum: "array", "string".
        :param pulumi.Input[_builtins.str] description: The description of an entitlement property.
        :param pulumi.Input[_builtins.str] external_value: The value of an entitlement property.
        :param pulumi.Input[_builtins.bool] multi_value: The property that determines if the entitlement property can hold multiple values.
        :param pulumi.Input[_builtins.str] name: The display name for an entitlement property.
        :param pulumi.Input[Union['EntitlementParentArgs', 'EntitlementParentArgsDict']] parent: Representation of a resource
        :param pulumi.Input[_builtins.str] parent_resource_orn: The Okta app instance, in ORN format.
        :param pulumi.Input[_builtins.str] value: The value of the entitlement property.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EntitlementArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Entitlement. This resource allows you to create and configure an Okta [Entitlement](https://developer.okta.com/docs/api/iga/openapi/governance.api/tag/Entitlements/).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.Entitlement("example", name="example")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/entitlement:Entitlement example <entitlement_id>
        ```

        :param str resource_name: The name of the resource.
        :param EntitlementArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EntitlementArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 external_value: Optional[pulumi.Input[_builtins.str]] = None,
                 multi_value: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[Union['EntitlementParentArgs', 'EntitlementParentArgsDict']]] = None,
                 parent_resource_orn: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EntitlementValueArgs', 'EntitlementValueArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EntitlementArgs.__new__(EntitlementArgs)

            if data_type is None and not opts.urn:
                raise TypeError("Missing required property 'data_type'")
            __props__.__dict__["data_type"] = data_type
            __props__.__dict__["description"] = description
            if external_value is None and not opts.urn:
                raise TypeError("Missing required property 'external_value'")
            __props__.__dict__["external_value"] = external_value
            if multi_value is None and not opts.urn:
                raise TypeError("Missing required property 'multi_value'")
            __props__.__dict__["multi_value"] = multi_value
            __props__.__dict__["name"] = name
            __props__.__dict__["parent"] = parent
            __props__.__dict__["parent_resource_orn"] = parent_resource_orn
            __props__.__dict__["value"] = value
            __props__.__dict__["values"] = values
        super(Entitlement, __self__).__init__(
            'okta:index/entitlement:Entitlement',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            data_type: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            external_value: Optional[pulumi.Input[_builtins.str]] = None,
            multi_value: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            parent: Optional[pulumi.Input[Union['EntitlementParentArgs', 'EntitlementParentArgsDict']]] = None,
            parent_resource_orn: Optional[pulumi.Input[_builtins.str]] = None,
            value: Optional[pulumi.Input[_builtins.str]] = None,
            values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EntitlementValueArgs', 'EntitlementValueArgsDict']]]]] = None) -> 'Entitlement':
        """
        Get an existing Entitlement resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] data_type: The data type of the entitlement property. If the entitlement property is multivalued, the data type is replaced with an array. Enum: "array", "string".
        :param pulumi.Input[_builtins.str] description: The description of an entitlement property.
        :param pulumi.Input[_builtins.str] external_value: The value of an entitlement property.
        :param pulumi.Input[_builtins.bool] multi_value: The property that determines if the entitlement property can hold multiple values.
        :param pulumi.Input[_builtins.str] name: The display name for an entitlement property.
        :param pulumi.Input[Union['EntitlementParentArgs', 'EntitlementParentArgsDict']] parent: Representation of a resource
        :param pulumi.Input[_builtins.str] parent_resource_orn: The Okta app instance, in ORN format.
        :param pulumi.Input[_builtins.str] value: The value of the entitlement property.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EntitlementState.__new__(_EntitlementState)

        __props__.__dict__["data_type"] = data_type
        __props__.__dict__["description"] = description
        __props__.__dict__["external_value"] = external_value
        __props__.__dict__["multi_value"] = multi_value
        __props__.__dict__["name"] = name
        __props__.__dict__["parent"] = parent
        __props__.__dict__["parent_resource_orn"] = parent_resource_orn
        __props__.__dict__["value"] = value
        __props__.__dict__["values"] = values
        return Entitlement(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="dataType")
    def data_type(self) -> pulumi.Output[_builtins.str]:
        """
        The data type of the entitlement property. If the entitlement property is multivalued, the data type is replaced with an array. Enum: "array", "string".
        """
        return pulumi.get(self, "data_type")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of an entitlement property.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="externalValue")
    def external_value(self) -> pulumi.Output[_builtins.str]:
        """
        The value of an entitlement property.
        """
        return pulumi.get(self, "external_value")

    @_builtins.property
    @pulumi.getter(name="multiValue")
    def multi_value(self) -> pulumi.Output[_builtins.bool]:
        """
        The property that determines if the entitlement property can hold multiple values.
        """
        return pulumi.get(self, "multi_value")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The display name for an entitlement property.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def parent(self) -> pulumi.Output[Optional['outputs.EntitlementParent']]:
        """
        Representation of a resource
        """
        return pulumi.get(self, "parent")

    @_builtins.property
    @pulumi.getter(name="parentResourceOrn")
    def parent_resource_orn(self) -> pulumi.Output[_builtins.str]:
        """
        The Okta app instance, in ORN format.
        """
        return pulumi.get(self, "parent_resource_orn")

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The value of the entitlement property.
        """
        return pulumi.get(self, "value")

    @_builtins.property
    @pulumi.getter
    def values(self) -> pulumi.Output[Optional[Sequence['outputs.EntitlementValue']]]:
        return pulumi.get(self, "values")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetUsersResult',
    'AwaitableGetUsersResult',
    'get_users',
    'get_users_output',
]

@pulumi.output_type
class GetUsersResult:
    """
    A collection of values returned by getUsers.
    """
    def __init__(__self__, compound_search_operator=None, delay_read_seconds=None, group_id=None, id=None, include_groups=None, include_roles=None, searches=None, users=None):
        if compound_search_operator and not isinstance(compound_search_operator, str):
            raise TypeError("Expected argument 'compound_search_operator' to be a str")
        pulumi.set(__self__, "compound_search_operator", compound_search_operator)
        if delay_read_seconds and not isinstance(delay_read_seconds, str):
            raise TypeError("Expected argument 'delay_read_seconds' to be a str")
        pulumi.set(__self__, "delay_read_seconds", delay_read_seconds)
        if group_id and not isinstance(group_id, str):
            raise TypeError("Expected argument 'group_id' to be a str")
        pulumi.set(__self__, "group_id", group_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if include_groups and not isinstance(include_groups, bool):
            raise TypeError("Expected argument 'include_groups' to be a bool")
        pulumi.set(__self__, "include_groups", include_groups)
        if include_roles and not isinstance(include_roles, bool):
            raise TypeError("Expected argument 'include_roles' to be a bool")
        pulumi.set(__self__, "include_roles", include_roles)
        if searches and not isinstance(searches, list):
            raise TypeError("Expected argument 'searches' to be a list")
        pulumi.set(__self__, "searches", searches)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)

    @_builtins.property
    @pulumi.getter(name="compoundSearchOperator")
    def compound_search_operator(self) -> Optional[_builtins.str]:
        """
        Search operator used when joining multiple search clauses
        """
        return pulumi.get(self, "compound_search_operator")

    @_builtins.property
    @pulumi.getter(name="delayReadSeconds")
    def delay_read_seconds(self) -> Optional[_builtins.str]:
        """
        Force delay of the users read by N seconds. Useful when eventual consistency of users information needs to be allowed for.
        """
        return pulumi.get(self, "delay_read_seconds")

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[_builtins.str]:
        """
        Find users based on group membership using the id of the group.
        """
        return pulumi.get(self, "group_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="includeGroups")
    def include_groups(self) -> Optional[_builtins.bool]:
        """
        Fetch group memberships for each user
        """
        return pulumi.get(self, "include_groups")

    @_builtins.property
    @pulumi.getter(name="includeRoles")
    def include_roles(self) -> Optional[_builtins.bool]:
        """
        Fetch user roles for each user
        """
        return pulumi.get(self, "include_roles")

    @_builtins.property
    @pulumi.getter
    def searches(self) -> Optional[Sequence['outputs.GetUsersSearchResult']]:
        """
        Filter to find user/users. Each filter will be concatenated with the compound search operator. Please be aware profile properties must match what is in Okta, which is likely camel case. Expression is a free form expression filter https://developer.okta.com/docs/reference/core-okta-api/#filter . The set name/value/comparison properties will be ignored if expression is present
        """
        return pulumi.get(self, "searches")

    @_builtins.property
    @pulumi.getter
    def users(self) -> Sequence['outputs.GetUsersUserResult']:
        """
        collection of users retrieved from Okta.
        """
        return pulumi.get(self, "users")


class AwaitableGetUsersResult(GetUsersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUsersResult(
            compound_search_operator=self.compound_search_operator,
            delay_read_seconds=self.delay_read_seconds,
            group_id=self.group_id,
            id=self.id,
            include_groups=self.include_groups,
            include_roles=self.include_roles,
            searches=self.searches,
            users=self.users)


def get_users(compound_search_operator: Optional[_builtins.str] = None,
              delay_read_seconds: Optional[_builtins.str] = None,
              group_id: Optional[_builtins.str] = None,
              include_groups: Optional[_builtins.bool] = None,
              include_roles: Optional[_builtins.bool] = None,
              searches: Optional[Sequence[Union['GetUsersSearchArgs', 'GetUsersSearchArgsDict']]] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUsersResult:
    """
    Get a list of users from Okta.


    :param _builtins.str compound_search_operator: Search operator used when joining multiple search clauses
    :param _builtins.str delay_read_seconds: Force delay of the users read by N seconds. Useful when eventual consistency of users information needs to be allowed for.
    :param _builtins.str group_id: Find users based on group membership using the id of the group.
    :param _builtins.bool include_groups: Fetch group memberships for each user
    :param _builtins.bool include_roles: Fetch user roles for each user
    :param Sequence[Union['GetUsersSearchArgs', 'GetUsersSearchArgsDict']] searches: Filter to find user/users. Each filter will be concatenated with the compound search operator. Please be aware profile properties must match what is in Okta, which is likely camel case. Expression is a free form expression filter https://developer.okta.com/docs/reference/core-okta-api/#filter . The set name/value/comparison properties will be ignored if expression is present
    """
    __args__ = dict()
    __args__['compoundSearchOperator'] = compound_search_operator
    __args__['delayReadSeconds'] = delay_read_seconds
    __args__['groupId'] = group_id
    __args__['includeGroups'] = include_groups
    __args__['includeRoles'] = include_roles
    __args__['searches'] = searches
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:user/getUsers:getUsers', __args__, opts=opts, typ=GetUsersResult).value

    return AwaitableGetUsersResult(
        compound_search_operator=pulumi.get(__ret__, 'compound_search_operator'),
        delay_read_seconds=pulumi.get(__ret__, 'delay_read_seconds'),
        group_id=pulumi.get(__ret__, 'group_id'),
        id=pulumi.get(__ret__, 'id'),
        include_groups=pulumi.get(__ret__, 'include_groups'),
        include_roles=pulumi.get(__ret__, 'include_roles'),
        searches=pulumi.get(__ret__, 'searches'),
        users=pulumi.get(__ret__, 'users'))
def get_users_output(compound_search_operator: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     delay_read_seconds: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     group_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     include_groups: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                     include_roles: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                     searches: Optional[pulumi.Input[Optional[Sequence[Union['GetUsersSearchArgs', 'GetUsersSearchArgsDict']]]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUsersResult]:
    """
    Get a list of users from Okta.


    :param _builtins.str compound_search_operator: Search operator used when joining multiple search clauses
    :param _builtins.str delay_read_seconds: Force delay of the users read by N seconds. Useful when eventual consistency of users information needs to be allowed for.
    :param _builtins.str group_id: Find users based on group membership using the id of the group.
    :param _builtins.bool include_groups: Fetch group memberships for each user
    :param _builtins.bool include_roles: Fetch user roles for each user
    :param Sequence[Union['GetUsersSearchArgs', 'GetUsersSearchArgsDict']] searches: Filter to find user/users. Each filter will be concatenated with the compound search operator. Please be aware profile properties must match what is in Okta, which is likely camel case. Expression is a free form expression filter https://developer.okta.com/docs/reference/core-okta-api/#filter . The set name/value/comparison properties will be ignored if expression is present
    """
    __args__ = dict()
    __args__['compoundSearchOperator'] = compound_search_operator
    __args__['delayReadSeconds'] = delay_read_seconds
    __args__['groupId'] = group_id
    __args__['includeGroups'] = include_groups
    __args__['includeRoles'] = include_roles
    __args__['searches'] = searches
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:user/getUsers:getUsers', __args__, opts=opts, typ=GetUsersResult)
    return __ret__.apply(lambda __response__: GetUsersResult(
        compound_search_operator=pulumi.get(__response__, 'compound_search_operator'),
        delay_read_seconds=pulumi.get(__response__, 'delay_read_seconds'),
        group_id=pulumi.get(__response__, 'group_id'),
        id=pulumi.get(__response__, 'id'),
        include_groups=pulumi.get(__response__, 'include_groups'),
        include_roles=pulumi.get(__response__, 'include_roles'),
        searches=pulumi.get(__response__, 'searches'),
        users=pulumi.get(__response__, 'users')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetUiSchemaResult',
    'AwaitableGetUiSchemaResult',
    'get_ui_schema',
    'get_ui_schema_output',
]

@pulumi.output_type
class GetUiSchemaResult:
    """
    A collection of values returned by getUiSchema.
    """
    def __init__(__self__, created=None, id=None, last_updated=None, ui_schema=None):
        if created and not isinstance(created, str):
            raise TypeError("Expected argument 'created' to be a str")
        pulumi.set(__self__, "created", created)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_updated and not isinstance(last_updated, str):
            raise TypeError("Expected argument 'last_updated' to be a str")
        pulumi.set(__self__, "last_updated", last_updated)
        if ui_schema and not isinstance(ui_schema, dict):
            raise TypeError("Expected argument 'ui_schema' to be a dict")
        pulumi.set(__self__, "ui_schema", ui_schema)

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.str:
        """
        Timestamp when the UI Schema was created. (ISO 86001).
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID property of an UI Schema.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> _builtins.str:
        """
        Timestamp when the UI Schema was last modified (ISO 86001).
        """
        return pulumi.get(self, "last_updated")

    @_builtins.property
    @pulumi.getter(name="uiSchema")
    def ui_schema(self) -> Optional['outputs.GetUiSchemaUiSchemaResult']:
        """
        - (Object) Representation of a resource.
        """
        return pulumi.get(self, "ui_schema")


class AwaitableGetUiSchemaResult(GetUiSchemaResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUiSchemaResult(
            created=self.created,
            id=self.id,
            last_updated=self.last_updated,
            ui_schema=self.ui_schema)


def get_ui_schema(id: Optional[_builtins.str] = None,
                  ui_schema: Optional[Union['GetUiSchemaUiSchemaArgs', 'GetUiSchemaUiSchemaArgsDict']] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUiSchemaResult:
    """
    Use this data source to retrieve information about an Okta UI Schema.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_ui_schema(id="ui_schema_id")
    ```


    :param _builtins.str id: The ID property of an UI Schema.
    :param Union['GetUiSchemaUiSchemaArgs', 'GetUiSchemaUiSchemaArgsDict'] ui_schema: - (Object) Representation of a resource.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['uiSchema'] = ui_schema
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getUiSchema:getUiSchema', __args__, opts=opts, typ=GetUiSchemaResult).value

    return AwaitableGetUiSchemaResult(
        created=pulumi.get(__ret__, 'created'),
        id=pulumi.get(__ret__, 'id'),
        last_updated=pulumi.get(__ret__, 'last_updated'),
        ui_schema=pulumi.get(__ret__, 'ui_schema'))
def get_ui_schema_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                         ui_schema: Optional[pulumi.Input[Optional[Union['GetUiSchemaUiSchemaArgs', 'GetUiSchemaUiSchemaArgsDict']]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUiSchemaResult]:
    """
    Use this data source to retrieve information about an Okta UI Schema.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_ui_schema(id="ui_schema_id")
    ```


    :param _builtins.str id: The ID property of an UI Schema.
    :param Union['GetUiSchemaUiSchemaArgs', 'GetUiSchemaUiSchemaArgsDict'] ui_schema: - (Object) Representation of a resource.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['uiSchema'] = ui_schema
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getUiSchema:getUiSchema', __args__, opts=opts, typ=GetUiSchemaResult)
    return __ret__.apply(lambda __response__: GetUiSchemaResult(
        created=pulumi.get(__response__, 'created'),
        id=pulumi.get(__response__, 'id'),
        last_updated=pulumi.get(__response__, 'last_updated'),
        ui_schema=pulumi.get(__response__, 'ui_schema')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetPrincipalRateLimitsResult',
    'AwaitableGetPrincipalRateLimitsResult',
    'get_principal_rate_limits',
    'get_principal_rate_limits_output',
]

@pulumi.output_type
class GetPrincipalRateLimitsResult:
    """
    A collection of values returned by getPrincipalRateLimits.
    """
    def __init__(__self__, created_by=None, created_date=None, default_concurrency_percentage=None, default_percentage=None, id=None, last_update=None, last_updated_by=None, org_id=None, principal_id=None, principal_type=None):
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if created_date and not isinstance(created_date, str):
            raise TypeError("Expected argument 'created_date' to be a str")
        pulumi.set(__self__, "created_date", created_date)
        if default_concurrency_percentage and not isinstance(default_concurrency_percentage, int):
            raise TypeError("Expected argument 'default_concurrency_percentage' to be a int")
        pulumi.set(__self__, "default_concurrency_percentage", default_concurrency_percentage)
        if default_percentage and not isinstance(default_percentage, int):
            raise TypeError("Expected argument 'default_percentage' to be a int")
        pulumi.set(__self__, "default_percentage", default_percentage)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_update and not isinstance(last_update, str):
            raise TypeError("Expected argument 'last_update' to be a str")
        pulumi.set(__self__, "last_update", last_update)
        if last_updated_by and not isinstance(last_updated_by, str):
            raise TypeError("Expected argument 'last_updated_by' to be a str")
        pulumi.set(__self__, "last_updated_by", last_updated_by)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if principal_id and not isinstance(principal_id, str):
            raise TypeError("Expected argument 'principal_id' to be a str")
        pulumi.set(__self__, "principal_id", principal_id)
        if principal_type and not isinstance(principal_type, str):
            raise TypeError("Expected argument 'principal_type' to be a str")
        pulumi.set(__self__, "principal_type", principal_type)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> _builtins.str:
        """
        The ID of the user who created the principal rate limit.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter(name="createdDate")
    def created_date(self) -> _builtins.str:
        """
        The date and time when the principal rate limit was created.
        """
        return pulumi.get(self, "created_date")

    @_builtins.property
    @pulumi.getter(name="defaultConcurrencyPercentage")
    def default_concurrency_percentage(self) -> _builtins.int:
        """
        The default concurrency percentage for the principal rate limit.
        """
        return pulumi.get(self, "default_concurrency_percentage")

    @_builtins.property
    @pulumi.getter(name="defaultPercentage")
    def default_percentage(self) -> _builtins.int:
        """
        The default percentage for the principal rate limit.
        """
        return pulumi.get(self, "default_percentage")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier of the principle rate limit entity.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> _builtins.str:
        return pulumi.get(self, "last_update")

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> _builtins.str:
        """
        The ID of the user who last updated the principal rate limit.
        """
        return pulumi.get(self, "last_updated_by")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> _builtins.str:
        """
        The unique identifier of the Okta organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> _builtins.str:
        """
        The unique identifier of the principal. This is the ID of the API token or OAuth 2.0 app.
        """
        return pulumi.get(self, "principal_id")

    @_builtins.property
    @pulumi.getter(name="principalType")
    def principal_type(self) -> _builtins.str:
        """
        The type of principal, either an API token or an OAuth 2.0 app.
        """
        return pulumi.get(self, "principal_type")


class AwaitableGetPrincipalRateLimitsResult(GetPrincipalRateLimitsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPrincipalRateLimitsResult(
            created_by=self.created_by,
            created_date=self.created_date,
            default_concurrency_percentage=self.default_concurrency_percentage,
            default_percentage=self.default_percentage,
            id=self.id,
            last_update=self.last_update,
            last_updated_by=self.last_updated_by,
            org_id=self.org_id,
            principal_id=self.principal_id,
            principal_type=self.principal_type)


def get_principal_rate_limits(id: Optional[_builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPrincipalRateLimitsResult:
    """
    Get the entitlements for a user and resource after evaluating all grants.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_principal_rate_limits(id="<principal_rate_limit_id>")
    ```


    :param _builtins.str id: The unique identifier of the principle rate limit entity.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getPrincipalRateLimits:getPrincipalRateLimits', __args__, opts=opts, typ=GetPrincipalRateLimitsResult).value

    return AwaitableGetPrincipalRateLimitsResult(
        created_by=pulumi.get(__ret__, 'created_by'),
        created_date=pulumi.get(__ret__, 'created_date'),
        default_concurrency_percentage=pulumi.get(__ret__, 'default_concurrency_percentage'),
        default_percentage=pulumi.get(__ret__, 'default_percentage'),
        id=pulumi.get(__ret__, 'id'),
        last_update=pulumi.get(__ret__, 'last_update'),
        last_updated_by=pulumi.get(__ret__, 'last_updated_by'),
        org_id=pulumi.get(__ret__, 'org_id'),
        principal_id=pulumi.get(__ret__, 'principal_id'),
        principal_type=pulumi.get(__ret__, 'principal_type'))
def get_principal_rate_limits_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPrincipalRateLimitsResult]:
    """
    Get the entitlements for a user and resource after evaluating all grants.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_principal_rate_limits(id="<principal_rate_limit_id>")
    ```


    :param _builtins.str id: The unique identifier of the principle rate limit entity.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getPrincipalRateLimits:getPrincipalRateLimits', __args__, opts=opts, typ=GetPrincipalRateLimitsResult)
    return __ret__.apply(lambda __response__: GetPrincipalRateLimitsResult(
        created_by=pulumi.get(__response__, 'created_by'),
        created_date=pulumi.get(__response__, 'created_date'),
        default_concurrency_percentage=pulumi.get(__response__, 'default_concurrency_percentage'),
        default_percentage=pulumi.get(__response__, 'default_percentage'),
        id=pulumi.get(__response__, 'id'),
        last_update=pulumi.get(__response__, 'last_update'),
        last_updated_by=pulumi.get(__response__, 'last_updated_by'),
        org_id=pulumi.get(__response__, 'org_id'),
        principal_id=pulumi.get(__response__, 'principal_id'),
        principal_type=pulumi.get(__response__, 'principal_type')))
